export default {
    "index": 36,
    "lineNumber": 1,
    "column": 37,
    "message": "Unexpected token a"
};